@@ -25,9 +25,11 @@ use std::io::Write;
 use std::ops::DerefMut;
 use std::sync::Arc;
 
-use futures::{AsyncReadExt, AsyncSeekExt};
+use futures::AsyncReadExt;
+use futures::AsyncSeekExt;
 use pyo3::buffer::PyBuffer;
-use pyo3::exceptions::{PyIOError, PyValueError};
+use pyo3::exceptions::PyIOError;
+use pyo3::exceptions::PyValueError;
 use pyo3::prelude::*;
 use pyo3_asyncio::tokio::future_into_py;
 use tokio::sync::Mutex;
@@ -46,8 +48,8 @@ enum FileState {
 }
 
 impl File {
-    pub fn new_reader(reader: ocore::BlockingReader, size: u64, capability: Capability) -> Self {
-        Self(FileState::Reader(reader.into_std_read(0..size)), capability)
+    pub fn new_reader(reader: ocore::StdReader, capability: Capability) -> Self {
+        Self(FileState::Reader(reader), capability)
     }
 
     pub fn new_writer(writer: ocore::BlockingWriter, capability: Capability) -> Self {
@@ -292,11 +294,9 @@ enum AsyncFileState {
 }
 
 impl AsyncFile {
-    pub fn new_reader(reader: ocore::Reader, size: u64, capability: Capability) -> Self {
+    pub fn new_reader(reader: ocore::FuturesAsyncReader, capability: Capability) -> Self {
         Self(
-            Arc::new(Mutex::new(AsyncFileState::Reader(
-                reader.into_futures_async_read(0..size),
-            ))),
+            Arc::new(Mutex::new(AsyncFileState::Reader(reader))),
             capability,
         )
     }
